@@ -1,8 +1,10 @@
+import sys
 from functools import partial
 from types import SimpleNamespace
 from .beacons import beacon_empty_line
 
 oprint = partial(print, flush=True)
+eprint = partial(print, flush=True, file=sys.stderr)
 
 _d = SimpleNamespace()
 
@@ -12,6 +14,11 @@ except:
     import json
 
 
+def print_trace():
+    import traceback
+    eprint(traceback.format_exc())
+
+
 def output_devnull(*args, **kwargs):
     pass
 
@@ -25,8 +32,15 @@ def output_stdout_ndjson(o, value):
 
 
 def output_eva_datapuller(o, value):
-    val_mode = o.endswith('.value')
-    s = f'{o[:-6 if val_mode else -7]} u '
+    if o.endswith('.value'):
+        s = f'{o[:-6]} u '
+        val_mode = True
+    elif o.endswith('.status'):
+        s = f'{o[:-7]} u '
+        val_mode = False
+    else:
+        s = f'{o} u '
+        val_mode = True
     oprint(s + (f'None {value}' if val_mode else str(value)))
 
 
